# Generated by Django 2.1.4 on 2018-12-10 11:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_company', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='account_number',
            field=models.CharField(max_length=100, verbose_name='account number'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='credit_limit',
            field=models.DecimalField(decimal_places=4, default=0, help_text='Credit limit - Negative value to allow discovery.', max_digits=12, verbose_name='credit limit'),
        ),
    ]
