{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-company:pyfb_company_provider_list' %}">{% trans "provider listing" %}</a></p>
<table class="table">
<tr><td>{% trans "enabled" %}</td><td>{{ object.supplier_enabled }}</td></tr>
<tr><td>{% trans "created" %}</td><td>{{ object.created }}</td></tr>
<tr><td>{% trans "modified" %}</td><td>{{ object.modified }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">{% trans "edit provider" %}</a>

{% endblock %}
