{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-company:pyfb_company_company_list' %}">{% trans "company listing" %}</a></p>
<table class="table">
<tr><td>{% trans "name" %}</td><td>{{ object.name }}</td></tr>
<tr><td>{% trans "created" %}</td><td>{{ object.created }}</td></tr>
<tr><td>{% trans "modified" %}</td><td>{{ object.modified }}</td></tr>
<tr><td>{% trans "address" %}</td><td>{{ object.address }}</td></tr>
<tr><td>{% trans "contact name" %}</td><td>{{ object.contact_name }}</td></tr>
<tr><td>{% trans "contact phone" %}</td><td>{{ object.contact_phone }}</td></tr>
<tr><td>{% trans "customer balance" %}</td><td>{{ object.customer_balance }}</td></tr>
<tr><td>{% trans "supplier balance" %}</td><td>{{ object.supplier_balance }}</td></tr>
<tr><td>{% trans "created" %}</td><td>{{ object.created }}</td></tr>
<tr><td>{% trans "modified" %}</td><td>{{ object.modified }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">{% trans "edit company" %}</a>

{% endblock %}
