# Generated by Django 2.1.4 on 2018-12-10 11:38

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_company', '0003_auto_20181210_1132'),
    ]

    operations = [
        migrations.RenameField(
            model_name='company',
            old_name='provider_balance',
            new_name='supplier_balance',
        ),
    ]
