{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-company:pyfb_company_companybalancehistory_list' %}">{% trans "balance history" %}</a></p>
<table class="table">
<tr><td>{% trans "amount debited" %}</td><td>{{ object.amount_debited }}</td></tr>
<tr><td>{% trans "amount refund" %}</td><td>{{ object.amount_refund }}</td></tr>
<tr><td>{% trans "customer balance" %}</td><td>{{ object.customer_balance }}</td></tr>
<tr><td>{% trans "supplier balance" %}</td><td>{{ object.supplier_balance }}</td></tr>
<tr><td>{% trans "operation type" %}</td><td>{{ object.operation_type }}</td></tr>
<tr><td>{% trans "external description" %}</td><td>{{ object.external_desc }}</td></tr>
<tr><td>{% trans "internal description" %}</td><td>{{ object.internal_desc }}</td></tr>
<tr><td>{% trans "created" %}</td><td>{{ object.created }}</td></tr>
<tr><td>{% trans "modified" %}</td><td>{{ object.modified }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">{% trans "edit" %}</a>

{% endblock %}
