{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-company:pyfb_company_provider_list' %}">{% trans "provider listing" %}</a></p>
<table class="table">
<tr>
<td>ID</td><td>{% trans "link" %}</td>
    <td>{% trans "enabled" %}</td>
</tr>
{% for object in object_list %}
<tr>
    <td>{{object.pk}}</td>
    <td><a href="{{object.get_absolute_url}}">{{object}}</a></td>
    <td>{{ object.supplier_enabled }}</td>
</tr>
{% endfor %}
</table><a class="btn btn-primary" href="{% url 'pyfb-company:pyfb_company_provider_create' %}">{% trans "create new provider" %}</a>
{% endblock %}
